@@ -1,14 +1,10 @@
 #! perl
 
-use 5.010.1;
+use 5.010;
 
 package App::Music::ChordPro;
 
-use App::Packager;
-
-use App::Music::ChordPro::Version;
-
-our $VERSION = $App::Music::ChordPro::Version::VERSION;
+our $VERSION = "0.72";
 
 =head1 NAME
 
@@ -29,30 +25,11 @@ one or many songs plus chord information. B<chordpro> will then
 generate a photo-ready, professional looking, impress-your-friends
 sheet-music suitable for printing on your nearest printer.
 
-Typical ChordPro input:
-
-    {title: Swing Low Sweet Chariot}
-    {subtitle: Traditional}
-
-    {start_of_chorus}
-    Swing [D]low, sweet [G]chari[D]ot,
-    Comin’ for to carry me [A7]home.
-    Swing [D7]low, sweet [G]chari[D]ot,
-    Comin’ for to [A7]carry me [D]home.
-    {end_of_chorus}
-
-    # Verse
-    I [D]looked over Jordan, and [G]what did I [D]see,
-    Comin’ for to carry me [A7]home.
-    A [D]band of angels [G]comin’ after [D]me,
-    Comin’ for to [A7]carry me [D]home.
-
-    {c: Chorus}
-
-B<chordpro> is a rewrite of the Chordii program.
+B<chordpro> is a rewrite of the Chordii program, see
+L<http://www.chordii.org>.
 
 For more information about the ChordPro file format, see
-L<https://www.chordpro.org>.
+L<http://www.chordpro.org>.
 
 =cut
 
@@ -60,35 +37,29 @@ L<https://www.chordpro.org>.
 
 use strict;
 use warnings;
-use Carp;
+use Data::Dumper;
 
 ################ The Process ################
 
 package main;
 
-our $options;
 our $config;
 
 package App::Music::ChordPro;
 
 sub ::run {
-    $options = app_setup( "ChordPro", $VERSION );
-    binmode(STDERR, ':utf8');
-    binmode(STDOUT, ':utf8');
+    my $options = app_setup( "ChordPro", $VERSION );
     $options->{trace}   = 1 if $options->{debug};
     $options->{verbose} = 1 if $options->{trace};
-    $options->{verbose} = 9 if $options->{debug};
-    main();
+    main($options);
 }
 
 sub main {
-    my ($opts) = @_;
-    $options = { %$options, %$opts } if $opts;
+    my ($options) = @_;
 
     # Establish backend.
     my $of = $options->{output};
-
-    if ( defined($of) && $of ne "" ) {
+    if ( $of ) {
         if ( $of =~ /\.pdf$/i ) {
             $options->{generate} ||= "PDF";
         }
@@ -108,51 +79,30 @@ sub main {
         elsif ( $of =~ /\.(crd|txt)$/i ) {
             $options->{generate} ||= "Text";
         }
-        elsif ( $of =~ /\.html?$/i ) {
-            $options->{generate} ||= "HTML";
-        }
         elsif ( $of =~ /\.(debug)$/i ) {
             $options->{generate} ||= "Debug";
         }
     }
-    elsif ( -t STDOUT ) {
-	# No output, and stdout is terminal.
-	# Derive output name from input name.
-	if ( @ARGV > 1 ) {
-	    # No default if more than one input document.
-	    die("Please use \"--output\" to specify the output file name\n");
-	}
-	my $f = $ARGV[0];
-	$f =~ s/\.\w+$/.pdf/;
-	$f .= ".pdf" if $f eq $ARGV[0];
-	$options->{output} = $f;
-	warn("Writing output to $f\n") if $options->{verbose};
-    }
-    else {
-	# Write output to stdout.
-	$options->{output} = "-";
-    }
 
     $options->{generate} ||= "PDF";
     my $pkg = "App::Music::ChordPro::Output::".$options->{generate};
     eval "require $pkg;";
     die("No backend for ", $options->{generate}, "\n$@") if $@;
     $options->{backend} = $pkg;
-    $pkg->version if $options->{verbose} && $pkg->can("version");
 
     # One configurator to bind them all.
     use App::Music::ChordPro::Config;
-    $config = App::Music::ChordPro::Config::configurator({});
+    $::config = App::Music::ChordPro::Config::configurator($options);
 
     # Parse the input(s).
     use App::Music::ChordPro::Songbook;
     my $s = App::Music::ChordPro::Songbook->new;
-    $s->parse_file($_) foreach @::ARGV;
+    $s->parsefile( $_, $options ) foreach @::ARGV;
 
     if ( $options->{'dump-chords'} ) {
 	my $d = App::Music::ChordPro::Song->new;
 	$d->{title} = "ChordPro $VERSION Built-in Chords";
-	$d->{subtitle} = [ "https://www.chordpro.org" ];
+	$d->{subtitle} = [ "http://www.chordpro.org" ];
 	my @body;
 	my @chords;
 
@@ -160,7 +110,7 @@ sub main {
 	foreach my $c ( @{ App::Music::ChordPro::Chords::chordnames() } ) {
 	    if ( $c =~ /^(.[b#]?)/ and $1 ne $prev )  {
 		$prev = $1;
-		push( @body, { type => "diagrams",
+		push( @body, { type => "chord-grids",
 			       context => "",
 			       origin => "__CLI__",
 			       chords => [ @chords ]
@@ -170,7 +120,7 @@ sub main {
 	    push( @chords, $c );
 	}
 
-	push( @body, { type => "diagrams",
+	push( @body, { type => "chord-grids",
 		       context => "",
 		       origin => "__CLI__",
 		       chords => [ @chords ]
@@ -186,35 +136,10 @@ sub main {
 	}
     }
 
-    warn(::dump($s), "\n") if $options->{debug};
+    warn(Dumper($s), "\n") if $options->{debug};
 
-    # Try interpolations.
-    if ( $of ) {
-	my $f = App::Music::ChordPro::Output::Common::fmt_subst
-	  ( $s->{songs}->[0], $of );
-	if ( $f ne $of ) {
-	    # Replace most non-alpha by underscore (but keep the extension).
-	    $f =~ s;(?!\.\w+$)[^\w/-];_;g;
-	    warn("Writing output to $f\n") if $options->{verbose};
-	    $options->{output} = $f;
-	}
-    }
-
-    my $res;
-
-    if ( my $xc = $::config->{settings}->{transcode} ) {
-	# Set target parser for the backend so it can find the transcoded
-	# chord definitions.
-	App::Music::ChordPro::Chords::set_parser($xc);
-	# Generate the songbook.
-	$res = $pkg->generate_songbook($s);
-	# Restore parser.
-	App::Music::ChordPro::Chords::set_parser($::config->{notes}->{system} );
-    }
-    else {
-	# Generate the songbook.
-	$res = $pkg->generate_songbook($s);
-    }
+    # Generate the songbook.
+    my $res = $pkg->generate_songbook( $s, $options );
 
     # Some backends write output themselves, others return an
     # array of lines to be written.
@@ -233,22 +158,6 @@ sub main {
     }
 }
 
-sub ::dump {
-    use Data::Dumper qw();
-    local $Data::Dumper::Sortkeys  = 1;
-    local $Data::Dumper::Indent    = 1;
-    local $Data::Dumper::Quotekeys = 0;
-    local $Data::Dumper::Deparse   = 1;
-    local $Data::Dumper::Terse     = 1;
-    local $Data::Dumper::Trailingcomma = 1;
-    local $Data::Dumper::Useperl = 1;
-    local $Data::Dumper::Useqq     = 0; # I want unicode visible
-
-    my $s = Data::Dumper::Dumper @_;
-    defined wantarray or warn $s;
-    return $s;
-}
-
 ################ Options and Configuration ################
 
 =head1 COMMAND LINE OPTIONS
@@ -257,67 +166,13 @@ sub ::dump {
 
 =item B<--about> (short: B<-A>)
 
-Prints version information about the ChordPro program. No other
-processing will be done.
-
-=item B<--back-matter=>I<FILE>
-
-Appends the contents of the named PDF document to the output. This can
-be used to produce documents with back matter pages.
-
-=item B<--config=>I<JSON> (shorter: B<--cfg>)
-
-A JSON file that defines the behaviour of the program and the layout
-of the output. See L<App::Music::ChordPro::Config> for details.
-
-This option may be specified more than once. Each additional config
-file overrides the corresponding definitions that are currently
-active.
-
-=item B<--cover=>I<FILE>
-
-See B<--front-matter>.
-
-=item B<--csv>
-
-When generating PDF output, also write a CSV file with titles and page
-numbers. Some tools, e.g., MobileSheets, can use the CSV to process
-the PDF as a collection of independent songs.
-
-The CSV has the same name  as the PDF, with extension C<.pdf> replaced
-by C<.csv>.
-
-=item B<--decapo>
-
-Eliminate capo settings by transposing the song.
-
-=item B<--diagrams=>I<WHICH>
-
-Prints diagrams of chords used in a song.
-
-I<WHICH> can be C<all> to print all chords used, C<user> to only print
-the user-defined chords, and C<none> to suppress printing of chord
-diagrams.
+About ChordPro.
 
 =item B<--encoding=>I<ENC>
 
 Specify the encoding for input files. Default is UTF-8.
 ISO-8859.1 (Latin-1) encoding is automatically sensed.
 
-=item B<--filelist=>I<FILE>
-
-Read the names of the files to be processed from the named file.
-
-This option may be specified multiple times.
-
-Song file names listed on the command line are processed I<after> the
-files from the filelist arguments.
-
-=item B<--front-matter=>I<FILE> B<--cover=>I<FILE>
-
-Prepends the contents of the named PDF document to the output. This can
-be used to produce documents with front matter (cover) pages.
-
 =item B<--lyrics-only> (short: B<-l>)
 
 Only prints lyrics. All chords are suppressed.
@@ -325,14 +180,6 @@ Only prints lyrics. All chords are suppressed.
 Useful to make prints for singers and other musicians that do not
 require chords.
 
-=item B<--no-csv>
-
-Suppresses generating the CSV file. See B<--toc>.
-
-=item B<--no-toc>
-
-Suppresses the table of contents. See B<--toc>.
-
 =item B<--output=>I<FILE> (short: B<-o>)
 
 Designates the name of the output file where the results are written
@@ -347,6 +194,10 @@ correspond to one of the backends that are currently supported:
 
 Portable document format (PDF).
 
+If a table of contents is generated with the PDF, ChordPro also writes
+a CSV file containing titles and page numbers. This CSV file has the
+same name as the PDF, with extenstion C<pdf> replaced by <csv>.
+
 =item txt
 
 A textual representation of the input, mostly for visual inspection.
@@ -357,6 +208,15 @@ A functional equivalent version of the ChordPro input.
 
 =back
 
+=item B<--config=>I<JSON> (shorter: B<--cfg>)
+
+A JSON file that defines the behaviour of the program and the layout
+of the output. See L<App::Music::ChordPro::Config> for details.
+
+This option may be specified more than once. Each additional config
+file overrides the corresponding definitions that are currently
+active.
+
 =item B<--start-page-number=>I<N> (short: B<-p>)
 
 Sets the starting page number for the output.
@@ -368,12 +228,20 @@ Includes a table of contents.
 By default a table of contents is included in the PDF output when
 it contains more than one song.
 
+=item B<--no-toc>
+
+Suppresses the table of contents.
+
 =item B<--transpose=>I<N> (short: -x)
 
 Transposes all songs by I<N> semi-tones. Note that I<N> may be
 specified as B<+>I<N> to transpose upward, using sharps, or as
 B<->I<N> to transpose downward, using flats.
 
+=item B<--user-chord-grids>
+
+Prints chord grids of all user defined chords used in a song.
+
 =item B<--version> (short: B<-V>)
 
 Prints the program version and exits.
@@ -387,9 +255,6 @@ not all of them actually do something.
 
 Options marked with * are better specified in the config file.
 
-B<Note:> Chordii used the term _grid_ for chord diagrams. It
-should not be confused with ChordPro grids.
-
 =over 4
 
 =item B<--text-font=>I<FONT> (short: B<-T>) *
@@ -418,15 +283,15 @@ Sets the font size for the chord names.
 
 =item B<--chord-grid-size=>I<N> (short: B<-s>) *
 
-Sets the total width of a chord diagram.
+Sets chord grid size (the total width of a chord grid).
 
 =item B<--chord-grids>
 
-Prints chord diagrams of all chords used in a song.
+Prints chord grids of all chords used in a song.
 
 =item B<--no-chord-grids> (short: B<-G>) *
 
-Disables printing of chord diagrams of the chords used in a song.
+Disables printing of chord grids of the chords used in a song.
 
 =item B<--easy-chord-grids>
 
@@ -438,16 +303,12 @@ Not supported.
 
 =item B<--chord-grids-sorted> (short: B<-S>) *
 
-Prints chord diagrams of the chords used in a song, ordered by key and
+Prints chord grids of the chords used in a song, ordered by key and
 type.
 
 =item B<--no-chord-grids-sorted> *
 
-Prints chord diagrams in the order they appear in the song.
-
-=item B<--user-chord-grids> *
-
-Prints chord diagrams of all user defined chords used in a song.
+Prints chord grids in the order they appear in the song.
 
 =item B<--even-pages-number-left> (short B<-L>)
 
@@ -459,7 +320,7 @@ Prints even/odd pages with pages numbers left on odd pages.
 
 =item B<--page-size=>I<FMT> (short: B<-P>) *
 
-Specifies the page size for the PDF output, e.g. C<a4> (default), C<letter>.
+Specifies page size, e.g. C<a4> (default), C<letter>.
 
 =item B<--single-space> (short B<-a>)) *
 
@@ -558,8 +419,8 @@ Don't use the specific config file, even if it exists.
 
 Sets a configuration item. I<item> must be in the format of
 colon-separated configuration keys, an equal sign, and the value. For
-example, the equivalent of B<--diagrams=none> is
-B<--define=diagrams:show=0>.
+example, the equivalent of B<--no-chord-grids> is
+B<--define=chordgrid:show=0>.
 
 B<--define> may be used multiple times to set multiple items.
 
@@ -573,14 +434,14 @@ configuration.
 
 =item B<--print-default-config>
 
-Prints the default configuration to standard output, and exits.
+Prints the default configuration, and exits.
 
 The default configuration is commented to explain its contents.
 
 =item B<--print-final-config>
 
 Prints the final configuration (after processing all system, user and
-other config files)  to standard output, and exits.
+other config files), and exits.
 
 The final configuration is not commented. Sorry.
 
@@ -592,11 +453,11 @@ The final configuration is not commented. Sorry.
 
 =item B<--help> (short: -h)
 
-Prints a help message. No other output is produced.
+Prints help message. No other output is produced.
 
 =item B<--manual>
 
-Prints the manual page. No other output is produced.
+Prints the manual. No other output is produced.
 
 =item B<--ident>
 
@@ -612,7 +473,6 @@ Provides more verbose information of what is going on.
 
 use Getopt::Long 2.13 qw( :config no_ignorecase );
 use File::Spec;
-use File::LoadLines;
 
 # Package name.
 my $my_package;
@@ -709,33 +569,26 @@ sub app_setup {
           ### Options ###
 
           "output|o=s",                 # Saves the output to FILE
+          "lyrics-only",                # Suppress all chords
           "generate=s",
           "backend-option|bo=s\%",
-	  "diagrams=s",			# Prints chord diagrams
           "encoding=s",
-	  "csv!",			# Generates contents CSV
-	  "front-matter|cover=s",	# Front matter page(s)
-	  "back-matter=s",		# Back matter page(s)
-	  "filelist=s@",		# List of input files
-	  "meta=s\%",			# Command line meta data
-	  "decapo",			# remove capo
+          "user-chord-grids!",          # Do[esn't] print grids for user defined chords.
 
           ### Standard Chordii Options ###
 
           "about|A" => \$about,         # About...
           "chord-font|C=s",             # Sets chord font
-          "chord-grid-size|s=f",        # Sets chord diagram size [30]
-          "chord-grids-sorted|S!",      # Prints chord diagrams ordered
+          "chord-grid-size|s=f",        # Sets chord grid size [30]
+          "chord-grids-sorted|S!",      # Prints chord grids ordered
           "chord-size|c=i",             # Sets chord size [9]
           "dump-chords|D",              # Dumps chords definitions (PostScript)
           "dump-chords-text|d" => \$dump_chords,  # Dumps chords definitions (Text)
-          "dump-chords-json" => sub { $dump_chords = 2},  # Dumps instrument defs (json).
           "even-pages-number-left|L",   # Even pages numbers on left
           "odd-pages-number-left",      # Odd pages numbers on left
           "lyrics-only|l",              # Only prints lyrics
-          "G" => sub { $clo->{'chord-grids'} = 0 },
-          "chord-grids!",               # En[dis]ables printing of chord diagrams
-          "easy-chord-grids|g!",        # Do[esn't] print diagrams for built-in "easy" chords. Ignored.
+          "chord-grids|G!",             # En[dis]ables printing of chord grids
+          "easy-chord-grids|g!",        # Do[esn't] print grids for built-in "easy" chords.
           "page-number-logical|n",      # Numbers logical pages, not physical
           "page-size|P=s",              # Specifies page size [letter, a4 (default)]
           "single-space|a!",            # Automatic single space lines without chords
@@ -745,8 +598,6 @@ sub app_setup {
           "i" => sub { $clo->{toc} = 1 },
           "toc!",                       # Generates a table of contents
           "transpose|x=i",              # Transposes by N semi-tones
-          "transcode|xc=s",             # Transcodes to another notation
-          "user-chord-grids!",          # Do[esn't] print diagrams for user defined chords.
           "version|V" => \$version,     # Prints version and exits
           "vertical-space|w=f",         # Extra vertical space between lines
           "2-up|2",                     # 2 pages per sheet
@@ -772,9 +623,9 @@ sub app_setup {
           'help|h|?'            => \$help,
           'help-config'         => sub { $manual = 2 },
           'manual'              => \$manual,
-          'verbose|v+',
+          'verbose|v',
           'trace',
-          'debug+',
+          'debug',
 
          ) )
     {
@@ -786,8 +637,9 @@ sub app_setup {
         # Load Pod::Usage only if needed.
         require Pod::Usage;
         Pod::Usage->import;
-	my $f = $manual == 2 ? "pod/Config.pod" : "pod/ChordPro.pod";
-        unshift( @_, -input => getresource($f) );
+        unshift( @_,
+		 -input => App::Packager::GetResource
+		 ( $manual == 2 ? "pod/Config.pod" : "pod/ChordPro.pod" ) );
         &pod2usage;
     };
 
@@ -818,12 +670,8 @@ sub app_setup {
     for my $config ( qw(config) ) {
         for ( $clo->{$config} ) {
             if ( defined($_) ) {
-                foreach my $c ( @$_ ) {
-		    # Check for resource names.
-		    if ( ! -r $c && $c !~ m;[/.]; ) {
-			$c = ::rsc_or_file($c);
-		    }
-                    die("$c: $!\n") unless -r $c;
+                foreach ( @$_ ) {
+                    die("$_: $!\n") unless -r $_;
                 }
                 next;
             }
@@ -839,56 +687,24 @@ sub app_setup {
         $clo->{"no$config"} = 1 unless $clo->{$config};
     }
 
-    # Decode command line strings.
-    # File names are dealt with elsewhere.
-    for ( qw(transcode) ) {
-	next unless defined $clo->{$_};
-	$clo->{$_} = decode_utf8($clo->{$_});
-    }
-    ####TODO: Should decode all, and remove filename exception.
-    for ( keys %{ $clo->{define} } ) {
-	$clo->{define}->{$_} = decode_utf8($clo->{define}->{$_});
-    }
-
     # Plug in command-line options.
     @{$options}{keys %$clo} = values %$clo;
-    $::options = $options;
-    # warn(::dump($options), "\n") if $options->{debug};
+    # warn(Dumper($options), "\n") if $options->{debug};
 
     if ( $defcfg || $fincfg ) {
-	print App::Music::ChordPro::Config::default_config()
+	print App::Music::ChordPro::Config::config_defaults()
 	  if $defcfg;
-	print App::Music::ChordPro::Config::config_final()
+	print App::Music::ChordPro::Config::config_final($options)
 	  if $fincfg;
 	exit 0;
     }
 
     if ( $dump_chords ) {
-	$::config = App::Music::ChordPro::Config::configurator($options);
 	require App::Music::ChordPro::Chords;
-	App::Music::ChordPro::Chords::dump_chords($dump_chords);
+	App::Music::ChordPro::Chords::dump_chords();
 	exit 0;
     }
 
-    if ( $clo->{filelist} ) {
-	my @files;
-	foreach ( @{ $clo->{filelist} } ) {
-	    my $list = loadlines( $_, $clo );
-	    foreach ( @$list ) {
-		next unless /\S/;
-		next if /^#/;
-		s/[\r\n]+$//;
-		push( @files, encode_utf8($_) );
-	    }
-	}
-	unshift( @ARGV, @files );
-    }
-
-    # At this point, there should be filename argument(s)
-    # unless we're embedded or just dumping chords.
-    app_usage(\*STDERR, 1)
-      unless $::__EMBEDDED__ || $clo->{'dump-chords'} || @ARGV;
-
     # Return result.
     $options;
 }
@@ -917,7 +733,7 @@ suitable for printing on your nearest printer.
 To learn more about ChordPro, look for the man page or do
 "chordpro --help" for the list of options.
 
-For more information, see https://www.chordpro.org .
+For more information, see http://www.chordpro.org .
 
 EndOfAbout
 
@@ -933,58 +749,49 @@ EndOfAbout
 
 sub app_usage {
     my ($fh, $exit) = @_;
-    my %cfg;
-    for ( qw( config userconfig sysconfig) ) {
-	$cfg{$_} = $configs{$_} || "no default";
-    }
     print ${fh} <<EndOfUsage;
 Usage: $0 [ options ] [ file ... ]
 
 Options:
     --about  -A                   About ChordPro...
-    --cover=FILE                  Add cover pages from PDF document
-    --diagrams=WHICH		  Prints chord diagrams
     --encoding=ENC                Encoding for input files (UTF-8)
-    --filelist=FILE               Reads song file names from FILE
     --lyrics-only  -l             Only prints lyrics
     --output=FILE  -o             Saves the output to FILE
     --config=JSON  --cfg          Config definitions (multiple)
     --start-page-number=N  -p     Starting page number [1]
     --toc --notoc -i              Generates/suppresses a table of contents
-    --decapo                      Eliminate capo settings
-    --transcode=SYS  -xc          Transcodes to notation system
     --transpose=N  -x             Transposes by N semi-tones
+    --user-chord-grids		  Prints the user defined chords in the song
     --version  -V                 Prints version and exits
 
 Chordii compatibility.
 Options marked with * are better specified in the config file.
 Options marked with - are ignored.
     --chord-font=FONT  -C         *Sets chord font
-    --chord-grid-size=N  -s       *Sets chord diagram size [30]
-    --chord-grids-sorted  -S      *Prints chord diagrams ordered by key
+    --chord-grid-size=N  -s       *Sets chord grid size [30]
+    --chord-grids-sorted  -S      *Prints chord grids ordered by key
     --chord-size=N  -c            *Sets chord size [9]
     --dump-chords  -D             Dumps chords definitions (PostScript)
     --dump-chords-text  -d        Dumps chords definitions (Text)
     --even-pages-number-left  -L  *Even pages numbers on left
     --odd-pages-number-left       *Odd pages numbers on left
-    --no-chord-grids  -G          *Disables printing of chord diagrams
+    --no-chord-grids  -G          *Disables printing of chord grids
     --no-easy-chord-grids  -g     Not supported
     --page-number-logical  -n     -Numbers logical pages, not physical
     --page-size=FMT  -P           *Specifies page size [letter, a4 (default)]
     --single-space  -a            *Automatic single space lines without chords
     --text-size=N  -t             *Sets text size [12]
     --text-font=FONT  -T          *Sets text font
-    --user-chord-grids		  *Prints the user defined chords in the song
     --vertical-space=N  -w        *Extra vertical space between lines
     --2-up  -2                    Not supported
     --4-up  -4                    Not supported
 
 Configuration options:
-    --config=CFG        Project specific config file ($cfg{config})
+    --config=CFG        Project specific config file ($configs{config})
     --noconfig          Don't use a project specific config file
-    --userconfig=CFG    User specific config file ($cfg{userconfig})
+    --userconfig=CFG    User specific config file ($configs{userconfig})
     --nouserconfig      Don't use a user specific config file
-    --sysconfig=CFG     System specific config file ($cfg{sysconfig})
+    --sysconfig=CFG     System specific config file ($configs{sysconfig})
     --nosysconfig       Don't use a system specific config file
     --nolegacyconfig    Don't use a Chord/Chordii legacy config file
     --nodefaultconfigs  -X  Don't use any default config files
@@ -1003,49 +810,15 @@ EndOfUsage
     exit $exit if defined $exit;
 }
 
-################ Resources ################
-
-use Encode qw(decode decode_utf8 encode_utf8);
-
-sub ::rsc_or_file {
-    my ( $c ) = @_;
-    my $f = $c;
-
-    # Check for resource names.
-    if ( $f !~ m;[/.]; ) {
-	if ( $c =~ /^(.+):(.*)/ ) {
-	    $f = lc($1) . "/" . lc($2) . ".json";
-	}
-	else {
-	    $f = lc($c) . ".json";
-	}
-    }
-
-    my @libs = split( /[:;]/, $ENV{CHORDPRO_LIB} || "." );
-    foreach my $lib ( @libs ) {
-	return $lib . "/" . $f if -r $lib . "/" . $f;
-	next if $f =~ /\//;
-	return $lib . "/config/" . $f if -r $lib . "/config/" . $f;
-    }
-
-    my $t = getresource($f);
-    $t = getresource( "config/$f" ) unless defined($t) || $f =~ /\//;
-    return defined($t) ? $t : $c;
-}
-
-use lib ( grep { defined } getresource("CPAN") );
-
 =head1 FONTS
 
 There are two ways to specify fonts: with a font filename, and a
 built-in font name.
 
 A font filename must be either and absolute filename, or a relative
-filename which is interpreted relative to the I<font path>, which
-consists of configuration setting C<fontdir>, the C<fonts> resource
-dir, and the contents of environment variable C<FONTDIR>. In any case,
-the filename should point to a valid TrueType (C<.ttf>) or OpenType
-(C<.otf>) font.
+filename which is interpreted relative to the configuration setting
+C<fontdir>. In any case, the filename should point to a valid TrueType
+(C<.ttf>) or OpenType (C<.otf>) font.
 
 If it is not a filename, it must be the name one of the built-in fonts.
 
@@ -1060,7 +833,7 @@ Built-in 'Adobe Core Fonts':
   Helvetica-BoldOblique
   Helvetica-Oblique
 
-Built-in 'Windows Fonts':
+Buitl-in 'Windows Fonts':
 
   Georgia                             Webdings
   Georgia,Bold                        Wingdings
@@ -1089,7 +862,7 @@ handling Unicode data. And that is fun to program in.
 
 =head1 CURRENT STATUS
 
-This program implements ChordPro version 5. It
+This program provides alpha support for ChordPro version 5. It
 supports most of the features of Chordii, and a lot more:
 
 * Native PDF generation
@@ -1098,8 +871,6 @@ supports most of the features of Chordii, and a lot more:
 
 * User defined chords and tuning, not limited to 6 strings.
 
-* Support for Nashville Numbering and Roman Numbering.
-
 * Support for external TrueType and OpenType fonts
 
 * Font kerning (with external TrueType fonts)
@@ -1110,27 +881,16 @@ supports most of the features of Chordii, and a lot more:
 
 (* = under development)
 
-=head1 AUTHOR
-
-Johan Vromans C<< <jv at CPAN dot org > >>
-
-=head1 SUPPORT
-
-ChordPro (the program) development is hosted on GitHub, repository
-L<https://github.com/ChordPro/chordpro>.
-
-Please report any bugs or feature requests to the GitHub issue tracker,
-L<https://github.com/ChordPro/chordpro/issues>.
-
-A user community discussing ChordPro can be found at
-L<https://groups.google.com/forum/#!forum/chordpro>.
-
 =head1 LICENSE
 
-Copyright (C) 2010,2018 Johan Vromans,
+Copyright (C) 2010,2016 Johan Vromans,
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This module is free software. You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
 
 =cut
 
