@@ -7,25 +7,12 @@ use warnings;
 
 use App::Music::ChordPro::Output::Common;
 
-my $re_meta;
-
 sub generate_songbook {
     my ($self, $sb, $options) = @_;
 
     # Skip empty songbooks.
     return [] unless eval { $sb->{songs}->[0]->{body} };
 
-    # Build regex for the known metadata items.
-    if ( $::config->{metadata}->{keys} ) {
-	$re_meta = '^(' .
-	  join( '|', map { quotemeta } @{$::config->{metadata}->{keys}} )
-	    . ')$';
-	$re_meta = qr/$re_meta/;
-    }
-    else {
-	undef $re_meta;
-    }
-
     my @book;
 
     foreach my $song ( @{$sb->{songs}} ) {
@@ -41,7 +28,6 @@ sub generate_songbook {
 }
 
 my $lyrics_only = 0;
-my @gridparams;
 
 sub generate_song {
     my ($s, $options) = @_;
@@ -54,10 +40,6 @@ sub generate_song {
 
     my @s;
 
-    if ( $s->{preamble} ) {
-	@s = @{ $s->{preamble} };
-    }
- 
     push(@s, "{title: " . $s->{meta}->{title}->[0] . "}")
       if defined $s->{meta}->{title};
     if ( defined $s->{subtitle} ) {
@@ -67,7 +49,7 @@ sub generate_song {
     if ( $s->{meta} ) {
 	foreach my $k ( sort keys %{ $s->{meta} } ) {
 	    next if $k =~ /^(?:title|subtitle)$/;
-	    if ( $variant eq 'msp' || $k =~ $re_meta ) {
+	    if ( $variant eq 'msp' ) {
 		push( @s, map { +"{$k: $_}" } @{ $s->{meta}->{$k} } );
 	    }
 	    else {
@@ -86,29 +68,15 @@ sub generate_song {
 
     # Move a trailing list of chords to the beginning, so the chords
     # are defined when the song is parsed.
-    if ( @{ $s->{body} } && $s->{body}->[-1]->{type} eq "diagrams"
-    	 && $s->{body}->[-1]->{origin} ne "__CLI__"
+    if ( @{ $s->{body} } && $s->{body}->[-1]->{type} eq "chord-grids"
+	 && $s->{body}->[-1]->{origin} ne "__CLI__"
        ) {
-    	unshift( @{ $s->{body} }, pop( @{ $s->{body} } ) );
-    }
-
-    if ( $s->{define} ) {
-	foreach my $info ( @{ $s->{define} } ) {
-	    my $t = "{define: " . $info->{name};
-	    $t .= " base-fret " . $info->{base};
-	    $t .= " frets " .
-	      join(" ", map { $_ < 0 ? "N" : $_ } @{$info->{frets}})
-		if $info->{frets};
-	    $t .= " fingers " .
-	      join(" ", map { $_ < 0 ? "N" : $_ } @{$info->{fingers}})
-		if $info->{fingers};
-	    push(@s, $t);
-	}
-	push(@s, "") if $tidy;
+	unshift( @{ $s->{body} }, pop( @{ $s->{body} } ) );
     }
 
     my $ctx = "";
     my $dumphdr = 1;
+    my @chorus;			# for chorus recall
 
     my @elts = @{$s->{body}};
     while ( @elts ) {
@@ -116,24 +84,11 @@ sub generate_song {
 
 	if ( $elt->{context} ne $ctx ) {
 	    push(@s, "{end_of_$ctx}") if $ctx;
-	    $ctx = $elt->{context};
-	    if ( $ctx ) {
-		if ( $elt->{type} eq "set" &&
-		     $elt->{name} eq "gridparams" ) {
-		    @gridparams = @{ $elt->{value} };
-		}
-		if ( @gridparams ) {
-		    my $t = "{start_of_$ctx ";
-		    $t .= $gridparams[2] . "+" if $gridparams[2];
-		    $t .= $gridparams[0];
-		    $t .= "x" . $gridparams[1] if $gridparams[1];
-		    $t .= "+" . $gridparams[3] if $gridparams[3];
-		    push( @s, $t );
-		}
-		else {
-		    push(@s, "{start_of_$ctx}");
-		}
-	    }
+	    push(@s, "{start_of_$ctx}") if $ctx = $elt->{context};
+	    @chorus = ( $elt ) if $ctx && $ctx eq "chorus";
+	}
+	elsif ( $elt->{context} eq "chorus" ) {
+	    push( @chorus, $elt );
 	}
 
 	if ( $elt->{type} eq "empty" ) {
@@ -165,11 +120,6 @@ sub generate_song {
 	    next;
 	}
 
-	if ( $elt->{type} eq "gridline" ) {
-	    push(@s, gridline($elt));
-	    next;
-	}
-
 	if ( $elt->{type} eq "verse" ) {
 	    push(@s, "") if $tidy;
 	    foreach my $e ( @{$elt->{body}} ) {
@@ -209,9 +159,8 @@ sub generate_song {
 		push( @s, "{chorus}" );
 	    }
 	    else {
-		unshift( @elts, @{ $elt->{chorus} } );
+		unshift( @elts, @chorus );
 	    }
-	    next;
 	}
 
 	if ( $elt->{type} eq "tab" ) {
@@ -232,19 +181,11 @@ sub generate_song {
 		    : $type eq 'comment_italic'
 		      ? 'comment'
 			: $type;
-		# Flatten chords/phrases.
-		if ( $elt->{chords} ) {
-		    $elt->{text} = "";
-		    for ( 0..$#{ $elt->{chords} } ) {
-			$elt->{text} .= "[" . $elt->{chords}->[$_] . "]"
-			  if $elt->{chords}->[$_] ne "";
-			$elt->{text} .= $elt->{phrases}->[$_];
-		    }
-		}
 		$text = fmt_subst( $s, $elt->{text} );
 	    }
 	    push(@s, "") if $tidy;
 	    push(@s, "{$type: $text}");
+	    push(@chorus, "{$type: $text}") if $elt->{context} eq "chorus";
 	    push(@s, "") if $tidy;
 	    next;
 	}
@@ -262,7 +203,7 @@ sub generate_song {
 	    next;
 	}
 
-	if ( $elt->{type} eq "diagrams" ) {
+	if ( $elt->{type} eq "chord-grids" ) {
 	    $dumphdr = 0 unless $elt->{origin} eq "__CLI__";
 	    push( @s,
 		  @{ App::Music::ChordPro::Chords::list_chords
@@ -277,16 +218,6 @@ sub generate_song {
 		$lyrics_only = $elt->{value}
 		  unless $lyrics_only > 1;
 	    }
-	    elsif ( $elt->{name} eq "gridparams" ) {
-		@gridparams = @{ $elt->{value} };
-	    }
-	    elsif ( $elt->{name} eq "transpose" ) {
-	    }
-	    next;
-	}
-
-	if ( $elt->{type} eq "ignore" ) {
-	    push( @s, $elt->{text} );
 	    next;
 	}
     }
@@ -310,39 +241,6 @@ sub songline {
     $line;
 }
 
-sub gridline {
-    my ($elt) = @_;
-
-    my $line = "";
-    for ( @{ $elt->{tokens} } ) {
-	$line .= " " if $line;
-	if ( $_->{class} eq "chord" ) {
-	    $line .= $_->{chord};
-	}
-	else {
-	    $line .= $_->{symbol};
-	}
-    }
-
-    if ( $elt->{comment} ) {
-	$line .= " " if $line;
-	my $res = "";
-	my $t = $elt->{comment};
-	if ( $t->{chords} ) {
-	    for ( 0..$#{ $t->{chords} } ) {
-		$res .= "[" . $t->{chords}->[$_] . "]" . $t->{phrases}->[$_];
-	    }
-	}
-	else {
-	    $res .= $t->{text};
-	}
-	$res =~ s/^\[\]//;
-	$line .= $res;
-    }
-
-    $line;
-}
-
 # Substitute %X sequences in title formats.
 sub fmt_subst {
     goto \&App::Music::ChordPro::Output::Common::fmt_subst;
